@@ -12,7 +12,7 @@ use List::Util qw(any);
 use Scalar::Util qw(blessed);
 use Encode qw(encode decode);
 
-our $VERSION = '2.01_04';
+our $VERSION = '2.01_05';
 
 # Basic attributes
 attr -host => hostname;
@@ -25,10 +25,9 @@ attr response_obj => 'Kelp::Response';
 # Debug
 attr long_error => $ENV{KELP_LONG_ERROR} // 0;
 
-# The charset is UTF-8 unless otherwise instructed
-attr -charset => sub {
-    $_[0]->config('charset') // 'UTF-8';
-};
+# The charset is set to UTF-8 by default in config module.
+# No default here because we want to support 'undef' charset
+attr charset => sub { $_[0]->config('charset') };
 
 # Name the config module
 attr config_module => 'Config';
@@ -44,6 +43,9 @@ attr -loaded_modules => sub { {} };
 attr req => undef;
 attr res => undef;
 
+# registered application encoder modules
+attr encoder_modules => sub { {} };
+
 # Initialization
 sub new
 {
@@ -392,6 +394,16 @@ sub charset_decode
     return decode $self->charset, $string;
 }
 
+sub get_encoder
+{
+    my ($self, $type, $name) = @_;
+
+    my $encoder = $self->encoder_modules->{$type} //
+        croak "No $type encoder";
+
+    return $encoder->get_encoder($name);
+}
+
 1;
 
 __END__
@@ -564,8 +576,12 @@ class will be used.
 
 =head2 charset
 
-Gets the encoding charset of the app. It will be C<UTF-8>, if not set to
-anything else. The charset can changed in the config files.
+Gets or sets the encoding charset of the app. It will be C<UTF-8>, if not set
+to anything else. The charset can also changed in the config files.
+
+If the charset is explicitly configured to be C<undef> or false, the
+application won't do any automatic encoding of responses or decoding of
+requests (unless a request defines its own charset).
 
 =head2 long_error
 
@@ -585,6 +601,7 @@ contain a reference to the current L<Kelp::Request> instance.
         }
     }
 
+
 =head2 res
 
 This attribute only makes sense if called within a route definition. It will
@@ -595,6 +612,11 @@ contain a reference to the current L<Kelp::Response> instance.
         $self->res->json->render( { success => 1 } );
     }
 
+=head2 encoder_modules
+
+A hash reference of registered encoder modules. Should only be interacted with
+through L</get_encoder> or inside encoder module's code.
+
 =head1 METHODS
 
 =head2 new
@@ -788,6 +810,24 @@ Shortcut methods, which encode or decode a string using the application's curren
 Returns whether the application is in production mode. Checks if L</mode> is
 either C<deployment> or C<production>.
 
+=head2 get_encoder
+
+    my $json_encoder = $self->get_encoder('json');
+
+Gets an instance of a given encoder. It takes two arguments:
+
+=over
+
+=item * type of the encoder module (eg. C<json>)
+
+=item * optional name of the encoder (default is C<default>)
+
+=back
+
+It will get extra config (if available) from C<encoders.TYPE.NAME>
+configuration hash. Will instantiate the encoder just once and then reuse it.
+Croaks when there is no such encoder type.
+
 =head1 AUTHOR
 
 Stefan Geneshky - minimal <at> cpan.org
