@@ -13,14 +13,15 @@ BEGIN {
     $ENV{KELP_TESTING} = 1;    # Set the ENV for testing
 }
 
-sub import {
+sub import
+{
     my ($me, @args) = @_;
 
     if ($args[0] && $args[0] eq -utf8) {
         my $builder = Test::More->builder;
-        binmode $builder->output,         ":encoding(utf8)";
+        binmode $builder->output, ":encoding(utf8)";
         binmode $builder->failure_output, ":encoding(utf8)";
-        binmode $builder->todo_output,    ":encoding(utf8)";
+        binmode $builder->todo_output, ":encoding(utf8)";
     }
 }
 
@@ -29,18 +30,19 @@ attr -psgi => undef;
 attr -app => sub {
     my $self = shift;
     return defined $self->psgi
-      ? Plack::Util::load_psgi( $self->psgi )
-      : die "'app' or 'psgi' parameter is required";
+        ? Plack::Util::load_psgi($self->psgi)
+        : die "'app' or 'psgi' parameter is required";
 };
 
-attr res  => sub { die "res is not initialized" };
+attr res => sub { die "res is not initialized" };
 
 attr cookies => sub { Kelp::Test::CookieJar->new };
 
-sub request {
-    my ( $self, $req ) = @_;
+sub request
+{
+    my ($self, $req) = @_;
     croak "HTTP::Request object needed" unless ref($req) eq 'HTTP::Request';
-    $self->note( $req->method . ' ' . $req->uri );
+    $self->note($req->method . ' ' . $req->uri);
 
     # Most likely the request was not initialized with a URI that had a scheme,
     # so we add a default http to prevent unitialized regex matches further
@@ -50,14 +52,14 @@ sub request {
     # If no host was given to the request's uri (most likely), then add
     # localhost. This is needed by the cookies header, which will not be
     # applied unless the request uri has a proper domain.
-    if ( $req->uri->opaque =~ qr|^/{1}| ) {
-        $req->uri->opaque( '//localhost' . $req->uri->opaque );
+    if ($req->uri->opaque =~ qr|^/{1}|) {
+        $req->uri->opaque('//localhost' . $req->uri->opaque);
     }
 
     # Add the current cookie to the request headers
     $self->cookies->add_cookie_header($req);
 
-    my $res = test_psgi( $self->app->run, sub { shift->($req) } );
+    my $res = test_psgi($self->app->run, sub { shift->($req) });
 
     # Extract the cookies from the response and add them to the cookie jar
     $self->cookies->extract_cookies($res);
@@ -66,30 +68,33 @@ sub request {
     return $self;
 }
 
-sub request_ok {
-    my ( $self, $req, $test_name ) = @_;
+sub request_ok
+{
+    my ($self, $req, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
-    $self->request($req)->code_is( 200, $test_name );
+    $self->request($req)->code_is(200, $test_name);
 }
 
-sub code_is {
-    my ( $self, $code, $test_name ) = @_;
+sub code_is
+{
+    my ($self, $code, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Response code is $code";
     is $self->res->code, $code, $test_name;
 
     # If we got 500 back and shouldn't have, we show the content
-    if ( $code != 500 && $self->res->code == 500 ) {
+    if ($code != 500 && $self->res->code == 500) {
         fail $self->res->content;
     }
 
     return $self;
 }
 
-sub code_isnt {
-    my ( $self, $code, $test_name ) = @_;
+sub code_isnt
+{
+    my ($self, $code, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Response code is not $code";
@@ -97,48 +102,53 @@ sub code_isnt {
     return $self;
 }
 
-sub content_is {
-    my ( $self, $value, $test_name ) = @_;
+sub content_is
+{
+    my ($self, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content is '$value'";
-    is $self->app->charset_decode( $self->res->content ), $value,
-      $test_name;
+    is $self->app->charset_decode($self->res->content), $value,
+        $test_name;
     return $self;
 }
 
-sub content_isnt {
-    my ( $self, $value, $test_name ) = @_;
+sub content_isnt
+{
+    my ($self, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content is not '$value'";
-    isnt $self->app->charset_decode( $self->res->content ), $value,
-      $test_name;
+    isnt $self->app->charset_decode($self->res->content), $value,
+        $test_name;
     return $self;
 }
 
-sub content_like {
-    my ( $self, $regexp, $test_name ) = @_;
+sub content_like
+{
+    my ($self, $regexp, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content matches $regexp";
-    like $self->app->charset_decode( $self->res->content ), $regexp,
-      $test_name;
+    like $self->app->charset_decode($self->res->content), $regexp,
+        $test_name;
     return $self;
 }
 
-sub content_unlike {
-    my ( $self, $regexp, $test_name ) = @_;
+sub content_unlike
+{
+    my ($self, $regexp, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content does not match $regexp";
-    unlike $self->app->charset_decode( $self->res->content ), $regexp,
-      $test_name;
+    unlike $self->app->charset_decode($self->res->content), $regexp,
+        $test_name;
     return $self;
 }
 
-sub content_type_is {
-    my ( $self, $value, $test_name ) = @_;
+sub content_type_is
+{
+    my ($self, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content-Type is '$value'";
@@ -146,8 +156,9 @@ sub content_type_is {
     return $self;
 }
 
-sub content_type_isnt {
-    my ( $self, $value, $test_name ) = @_;
+sub content_type_isnt
+{
+    my ($self, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Content-Type is not '$value'";
@@ -155,52 +166,57 @@ sub content_type_isnt {
     return $self;
 }
 
-sub header_is {
-    my ( $self, $header, $value, $test_name ) = @_;
+sub header_is
+{
+    my ($self, $header, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Header '$header' => '$value'";
     is $self->res->header($header), $value, $test_name
-      || $self->diag_headers();
+        || $self->diag_headers();
     return $self;
 }
 
-sub header_isnt {
-    my ( $self, $header, $value, $test_name ) = @_;
+sub header_isnt
+{
+    my ($self, $header, $value, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Header '$header' is not '$value'";
     isnt $self->res->header($header), $value, $test_name
-      || $self->diag_headers();
+        || $self->diag_headers();
     return $self;
 }
 
-sub header_like {
-    my ( $self, $header, $regexp, $test_name ) = @_;
+sub header_like
+{
+    my ($self, $header, $regexp, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Header '$header' =~ $regexp";
     like $self->res->header($header), $regexp, $test_name
-      || $self->diag_headers();
+        || $self->diag_headers();
     return $self;
 }
 
-sub header_unlike {
-    my ( $self, $header, $regexp, $test_name ) = @_;
+sub header_unlike
+{
+    my ($self, $header, $regexp, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "Header '$header' !~ $regexp";
     unlike $self->res->header($header), $regexp, $test_name
-      || $self->diag_headers();
+        || $self->diag_headers();
     return $self;
 }
 
-sub json_content {
+sub json_content
+{
     my $self = shift;
     fail "No JSON decoder" unless $self->app->can('json');
     my $result;
     try {
-        $result = $self->app->json->decode( $self->res->content );
+        $result = $self->app->json->decode($self->res->content);
     }
     catch {
         fail("Poorly formatted JSON");
@@ -208,31 +224,35 @@ sub json_content {
     return $result;
 }
 
-sub json_cmp {
-    my ( $self, $expected, $test_name ) = @_;
+sub json_cmp
+{
+    my ($self, $expected, $test_name) = @_;
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test_name ||= "JSON structure matches";
     like $self->res->header('content-type'), qr/json/, 'Content-Type is JSON'
-      or return $self;
+        or return $self;
     my $json = $self->json_content;
-    cmp_deeply( $json, $expected, $test_name ) or diag explain $json;
+    cmp_deeply($json, $expected, $test_name) or diag explain $json;
     return $self;
 }
 
-sub note {
+sub note
+{
     my $self = shift;
     Test::More::note @_;
     return $self;
 }
 
-sub diag_headers {
+sub diag_headers
+{
     my $self = shift;
     diag $self->res->headers->as_string;
     return $self;
 }
 
-sub diag_content {
+sub diag_content
+{
     my $self = shift;
     diag $self->res->content;
     return $self;
